@@ -6,8 +6,7 @@ trap on_exit EXIT
 set -euo pipefail
 IFS=$'\n\t'
 
-#SECURITY_PARTNERS_REPOSITORY='git@ssh.dev.azure.com:v3/dotnet-security-partners/dotnet/dotnet'
-SECURITY_PARTNERS_REPOSITORY='https://dotnet-security-partners@dev.azure.com/dotnet-security-partners/dotnet/_git/dotnet'
+SECURITY_PARTNERS_REPOSITORY='git@ssh.dev.azure.com:v3/dotnet-security-partners/dotnet/dotnet'
 MS_TARBALL_SHA512_HASH='d16f6b6713a79aaeabaf1043c4d649de8f6e07d9f575fedcbbaee993a32259046641a4c5680885a3a3a686df04429c51e934ee1a476ad2e75ed7ea94cc9a63b8'
 
 INITIAL_DIRECTORY=$PWD
